==> freedroidrpg-1.0rc2-2-x86_64.pkg.tar.zst: usr/share/freedroidrpg/data/storyline/act1/titles/it/EndOfAct.lua <==
---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "HellFortressTwo.ogg",
voice_acting = "EndOfAct.ogg",
preroll_text = 2,
postroll_text = 5,
text = [[
    Ti stai divertendo?
  Io no.

I robot sembrano molto peturbati da qualcosa.
Suppongo che sono arrabbiate contro di te.
Almeno hanno smesso di cercarmi.
Quite a? Relief?

C'è un'Intelligenza Artificiale nella tua regione.
Si è chiamata "Singolarità".
O qualcosa di simile.
Non riesco a capire ciò che vuole.
Ti terrò informato.

Oh a proposito...
I'm still waiting for you.
I haven't moved an inch since you woke up.
Now that the beloved town of yours is safe...
...Wouldn't it be a good time to save me as well?

            Dvorak, prima IA.



=== END OF ACT 1 ===
]]
}

==> freedroidrpg-1.0-4-x86_64.pkg.tar.zst: usr/share/freedroidrpg/data/storyline/act1/titles/it/EndOfAct.lua <==
---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "HellFortressTwo.ogg",
voice_acting = "EndOfAct.ogg",
preroll_text = 2,
postroll_text = 5,
text = [[
    Ti stai divertendo?
  Io no.

I robot sembrano molto peturbati da qualcosa.
Suppongo che sono arrabbiate contro di te.
Almeno hanno smesso di cercarmi.
Un bel? Sollievo?

C'è un'Intelligenza Artificiale nella tua regione.
Si è chiamata "Singolarità".
O qualcosa di simile.
Non riesco a capire ciò che vuole.
Ti terrò informato.

Oh a proposito...
Ti sto ancora aspettando.
Non mi sono mosso di un centimetro da quando ti sei risvegliato.
Ora che la tua amata città è salva...
...Non sarebbe il momento giusto per salvare anche me?

            Dvorak, prima IA.



=== FINE DEL 1° ATTO ===

]]
}
